#
# spec file for package python-detox
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-detox
Version:        0.18
Release:        2.20
Summary:        Distributed variant of the tox tool
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/tox-dev/detox
Source:         https://files.pythonhosted.org/packages/source/d/detox/detox-%{version}.tar.gz
# PATCH-FIX-UPSTREAM 0001-Specify-encoding-when-reading-README-and-CHANGELOG.patch -- https://github.com/tox-dev/detox/pull/39
Patch1:         0001-Specify-encoding-when-reading-README-and-CHANGELOG.patch
BuildRequires:  %{python_module eventlet >= 0.15.0}
BuildRequires:  %{python_module py >= 1.4.27}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tox >= 2}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-eventlet >= 0.15.0
Requires:       python-py >= 1.4.2713
Requires:       python-tox >= 2
BuildArch:      noarch
%python_subpackages

%description
detox is the distributed version of "tox".  It makes efficient use of multiple
CPUs by running all possible activities in parallel.  It has the same options
and configuration that tox has so after installation can just run:

    detox

in the same way and with the same options with which you would run
tox, see the tox home page for more info.

%prep
%setup -q -n detox-%{version}
%patch1 -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PATH="$PATH:%{buildroot}%{_bindir}"
# All 3 skipped tests just timeout in OBS
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} py.test-%{$python_version} -k 'not (test_createsdist or test_getvenv or test_test or test_runtests or test_developpkg)'

%files %{python_files}
%license LICENSE
%doc CHANGELOG
%python3_only %{_bindir}/detox
%{python_sitelib}/*

%changelog
* Wed Jan  2 2019 tbechtold@suse.com
- update to 0.18:
  - integrate usable fixes from stale PR7
  - (fix [#20](https://github.com/tox-dev/detox/issues/20) detox
    ignores/breaks usedevelop - by Kendall Chuang
  - (fix [#21](https://github.com/tox-dev/detox/issues/21)
    detox doesn't support skipsdist config option - by Kendall Chuang
  - convert changelog to markdown and render as part of description on PyPI
  - detox version now prints own version and then what tox has to say
  - add extra dependencies in setup.py
  - update tests to current pytest API
  - use black for code formatting
  - use flake8 for linting
  - add descriptions to tox envs
  - add a "dev" tox env
  - (fix [#23](https://github.com/tox-dev/detox/issues/23)) do not
    swallow exceptions - by @vlaci
  (fix [#16](https://github.com/tox-dev/detox/issues/16)) use tox
    quiet level to make detox quiet - by Oliver Bestwalter
  - and now the markdown description might even be rendered
  - *sigh* replace hardcoded long description with actual content of
    `README.md`
  - propagate information about new location of issie tracker to PyPI
  - (fix [#15](https://github.com/tox-dev/detox/issues/15)) make detox
    aware of new way to fetch a package in tox 3.3 - by Oliver
    Bestwalter
  - (fix [#15](https://github.com/tox-dev/detox/issues/15)) make detox
    aware of new way to fetch a package in tox 3.3 - by Oliver
    Bestwalter
  - (fix [#25](https://github.com/tox-dev/detox/issues/25)) print out
    detox version rather than tox version including detox version as
    plugin, when invoking [detox --version]{.title-ref} - by Oliver
    Bestwalter
- Add 0001-Specify-encoding-when-reading-README-and-CHANGELOG.patch
* Tue Sep 18 2018 tchvatal@suse.com
- Skip one more test failing in OBS
* Mon Sep 17 2018 tchvatal@suse.com
- Fix homepage url to point to active github
* Sat Aug 25 2018 jengelh@inai.de
- Use noun phrase in summary.
* Thu Aug 23 2018 tchvatal@suse.com
- Switch to singlespec
- Run tests
- Update to 0.13:
  * get compatible again to tox-2.0
  * Add support for running detox as python -m detox
  * use pytest for testing
* Sat May  2 2015 benoit.monin@gmx.fr
- update to version 0.9.4:
  * get compatible again to eventlet by avoiding to import
    eventlet.processes, thanks Takeshi Komiya for the PR.
  * make detox honor skipsdist.  Thanks Timoth Messier for the PR.
  * change license to MIT
- change license to match upstream
- increase required versions for eventlet and tox
* Wed Aug  6 2014 toddrme2178@gmail.com
- Update to 0.9.3
  - fix issue6: quickly make detox work with tox-1.6 again
    (although not all 1.6 features supported, e.g. --develop
    does not work)
  - fix issue3: don't claim a TROVE identifier of "python3"
    because detox itself depends on eventlet which does not work
    on  py3 yet. (Nevertheless detox will create py3 environments
    through tox of course)
  - fix issue1: support python2.5 again (although we might drop it
    in the future -- it's enough of tox/detox can _create_ and
    handle py25 environments, they don't neccessarily need to
    support running themself on py25)
* Tue Jul 30 2013 speilicke@suse.com
- Initial version
